package xeg

import (
	"context"
	"time"

	"gitlab.wanzhuangkj.com/tush/xpkg/xerrors/xerror"
	"golang.org/x/sync/errgroup"
)

type FnCtx func(ctx context.Context) error

func Do(ctx context.Context, fns ...FnCtx) error {
	if len(fns) == 0 {
		return nil
	}
	ctx, cancel := context.WithCancel(ctx)
	defer cancel()
	g, ctx := errgroup.WithContext(ctx)
	for _, fn := range fns {
		g.Go(func() error {
			return fn(ctx)
		})
	}
	err := g.Wait()
	if err != nil {
		return xerror.New(err.Error())
	}
	return nil
}

func DoWithTimeout(timeout time.Duration, fns ...FnCtx) error {
	if len(fns) == 0 {
		return nil
	}
	ctx, cancel := context.WithTimeout(context.Background(), timeout)
	defer cancel()
	g, ctx := errgroup.WithContext(ctx)
	for _, fn := range fns {
		g.Go(func() error {
			return fn(ctx)
		})
	}
	err := g.Wait()
	if err != nil {
		return xerror.New(err.Error())
	}
	return nil
}
